package be.iminds.ilabt.jfed.espec.util;

import be.iminds.ilabt.jfed.espec.model.*;

import javax.annotation.Nonnull;
import java.util.List;

/**
 * ESpecLogListener is used to get feedback about all ExperimentSpecification actions and steps
 *
 * Do not expect to be all calls to be on the same thread!
 * This means that you might theoretically get some of the onPostExecute() calls after the onPostExecuteAll() call...
 */
public interface ESpecLogListener {
    void onPreFileLoad();
    void onPostFileLoad(@Nonnull FileSource fileSource, boolean isFast, long byteSize, boolean success);
    void onPostFileLoadAll(boolean success);

    void onPreRSpec();
    void onPostRSpec(@Nonnull RspecSpec rspec, boolean success);
    void onPostRspecAll(boolean success, @Nonnull List<String> allNodeClientIds);

    void onPreDir();
    void onPostDir(@Nonnull DirSpec dir, @Nonnull String fullPath, @Nonnull String nodeClientId, boolean success);
    void onPostDirAll(boolean success);

    void onPreUpload();
    void onPostUpload(@Nonnull UploadLikeSpec uploadSpec, @Nonnull String fullPath, @Nonnull String nodeClientId, boolean success);
    void onPostUploadAll(boolean success);

    void onPreExecute();
    void onPostExecute(@Nonnull ExecuteSpec executeSpec, @Nonnull String fullPath, @Nonnull String nodeClientId, int exitStatus, boolean success);
    void onPostExecuteStepAll(@Nonnull ExecuteSpec executeSpec, boolean success);
    void onPostExecuteAll(boolean success);

    void onPreAnsible();
    void onPostAnsiblePlaybook(@Nonnull AnsiblePlaybookSpec ansiblePlaybookSpec, @Nonnull String fullPath, @Nonnull String nodeClientId, boolean success);
    void onPostAnsibleAll(boolean success);
}
